var crumbsFactory = function crumbsFactory(context) {
  return {
    // getters
    crumbs: context.$store.getters.__crumbs,
    separator: context.$store.getters.__separator,
    hidden: context.$store.getters.__hidden,
    // actions
    syncStore: function syncStore(label) {
      context.$store.dispatch('BREADCRUMB_SYNC_STORE', {
        label: label
      });
    },
    syncRoute: function syncRoute(routes) {
      context.$store.dispatch('BREADCRUMB_SYNC_ROUTE', routes);
    }
  };
};

var crumbStore = {
  state: {
    crumbs: [],
    separator: '',
    hidden: [],
    loading: false
  },
  getters: {
    __crumbs: function __crumbs(_ref) {
      var crumbs = _ref.crumbs;
      return crumbs;
    },
    __separator: function __separator(_ref2) {
      var separator = _ref2.separator;
      return separator;
    },
    __loading: function __loading(_ref3) {
      var loading = _ref3.loading;
      return loading;
    },
    __hidden: function __hidden(_ref4) {
      var hidden = _ref4.hidden;
      return hidden;
    }
  },
  mutations: {
    SYNC_STORE: function SYNC_STORE(state, crumbs) {
      return state.crumbs = crumbs;
    },
    SYNC_ROUTE: function SYNC_ROUTE(state, crumbs) {
      return state.crumbs = crumbs;
    },
    SET_SEPARATOR: function SET_SEPARATOR(state, separator) {
      return state.separator = separator;
    },
    SET_HIDDEN: function SET_HIDDEN(state, hidden) {
      return state.hidden = hidden;
    }
  },
  actions: {
    BREADCRUMB_SYNC_STORE: function BREADCRUMB_SYNC_STORE(_ref5, _ref6) {
      var commit = _ref5.commit,
          getters = _ref5.getters;
      var label = _ref6.label;
      var crumbs = getters['__crumbs'];
      var hidden = getters['__hidden'];
      var name = crumbs[crumbs.length - 1].name;
      var remaped = crumbs.map(function (crumb) {
        return crumb.name === name && {
          name: crumb.name,
          path: crumb.path,
          meta: crumb.meta,
          params: crumb.params,
          redirect: crumb.redirect,
          label: label
        } || crumb;
      }).filter(function (crumb) {
        return !hidden.includes(crumb.name);
      });
      commit('SYNC_STORE', remaped);
    },
    BREADCRUMB_SYNC_ROUTE: function BREADCRUMB_SYNC_ROUTE(_ref7, _ref8) {
      var commit = _ref7.commit,
          getters = _ref7.getters;
      var fullPath = _ref8.fullPath,
          name = _ref8.name,
          matched = _ref8.matched,
          _ref8$query = _ref8.query,
          query = _ref8$query === void 0 ? {} : _ref8$query,
          _ref8$params = _ref8.params,
          params = _ref8$params === void 0 ? {} : _ref8$params;
      var crumbs = getters['__crumbs'];
      var hidden = getters['__hidden'];

      function getParam(route, crumb, index) {
        var _query = Object.values(query)[Object.keys(query).length - 1];

        var _params = Object.keys(params).length > 1 ? fullPath.split('/')[index] : Object.values(params)[Object.keys(params).length - 1];

        if (!crumb.name) return undefined;
        return crumb.name && (route === crumb.name && (_params || _query) || _query) || (crumbs.find(function (_crumb) {
          return _crumb.name === crumb.name;
        }) || {}).label;
      }

      var added = matched.map(function (crumb, index) {
        return {
          name: crumb.name,
          path: crumb.path,
          meta: crumb.meta,
          params: crumb.params,
          redirect: crumb.redirect,
          label: getParam(name, crumb, index)
        };
      }).filter(function (route) {
        return !hidden.includes(route.name);
      });
      commit('SYNC_ROUTE', added);
    },
    BREADCRUMB_SET_SEPARATOR: function BREADCRUMB_SET_SEPARATOR(_ref9, separator) {
      var commit = _ref9.commit;
      return commit('SET_SEPARATOR', separator);
    },
    BREADCRUMB_SET_HIDDEN: function BREADCRUMB_SET_HIDDEN(_ref10, hidden) {
      var commit = _ref10.commit;
      return commit('SET_HIDDEN', hidden);
    }
  }
};

var registerStore = function registerStore(store, storeName) {
  store.registerModule(storeName, Object.assign({}, crumbStore));
};

var index = {
  install: function install(Vue, store) {
    var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

    if (!store) {
      console.error('stack need store');
      return false;
    }

    var storeName = options.storeName,
        separatorText = options.separatorText,
        hidden = options.hidden;
    if (!storeName) storeName = 'coebreadcrumb';
    if (!separatorText) separatorText = '|';
    if (!hidden) hidden = [];
    registerStore(store, storeName);
    store.dispatch('BREADCRUMB_SET_SEPARATOR', separatorText);
    store.dispatch('BREADCRUMB_SET_HIDDEN', hidden);
    Object.defineProperty(Vue.prototype, '$breadcrumb', {
      get: function get() {
        return crumbsFactory(this);
      }
    });
    Vue.mixin({
      mounted: function mounted() {
        var _this = this;

        if (this.$options.breadcrumb) {
          var λ = this.$options.breadcrumb.getters;
          store.watch(function () {
            return store.getters[λ];
          }, function (label) {
            return _this.$breadcrumb.syncStore(label);
          });
        }
      }
    });
  }
};

//
//
//
//
//
//
//
//
//
//
//
//
//
//
var script = {
  name: 'coe-breadcrumb',
  watch: {
    '$route': {
      handler: 'syncRoute',
      immediate: true
    }
  },
  computed: {
    separator: function separator() {
      return {
        '--separator': "'".concat(this.$breadcrumb.separator, "'")
      };
    }
  },
  methods: {
    isActive: function isActive(crumb) {
      if (!crumb) return false;
      var currentName = this.$breadcrumb.crumbs.length && this.$breadcrumb.crumbs[this.$breadcrumb.crumbs.length - 1].name;
      return currentName === crumb.name;
    },
    getType: function getType(crumb) {
      return this.isActive(crumb) && 'div' || 'router-link';
    },
    getClasses: function getClasses(crumb) {
      return ['link', {
        '-active': this.isActive(crumb)
      }];
    },
    getLabel: function getLabel(crumb) {
      return crumb.label || crumb.name || 'Início';
    },
    redirect: function redirect(crumb) {
      return !crumb.path && '/' || crumb;
    },
    syncRoute: function syncRoute(_ref) {
      var fullPath = _ref.fullPath,
          name = _ref.name,
          matched = _ref.matched,
          query = _ref.query,
          params = _ref.params;
      this.$breadcrumb.syncRoute({
        fullPath: fullPath,
        name: name,
        matched: matched,
        query: query,
        params: params
      });
    }
  }
};

/* script */
            const __vue_script__ = script;
            
/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    { staticClass: "coe-breadcrumb" },
    [
      _vm._t(
        "crumbs",
        [
          _c(
            "ul",
            { staticClass: "breadcrumbs" },
            _vm._l(_vm.$breadcrumb.crumbs, function(crumb, index) {
              return _c(
                "li",
                { key: index, staticClass: "crumb", style: _vm.separator },
                [
                  _c(
                    _vm.getType(crumb),
                    {
                      tag: "component",
                      class: _vm.getClasses(crumb),
                      attrs: { to: _vm.redirect(crumb) }
                    },
                    [
                      _vm._t("crumbs", [_vm._v(_vm._s(_vm.getLabel(crumb)))], {
                        label: _vm.getLabel(crumb)
                      })
                    ],
                    2
                  )
                ],
                1
              )
            })
          )
        ],
        { crumbs: _vm.$breadcrumb.crumbs }
      )
    ],
    2
  )
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  const __vue_inject_styles__ = function (inject) {
    if (!inject) return
    inject("data-v-5ccd4980_0", { source: "\n.coe-breadcrumb[data-v-5ccd4980] {\n}\n.breadcrumbs[data-v-5ccd4980] {\n  display: flex;\n  margin: 0;\n  padding: 0;\n}\n.crumb[data-v-5ccd4980] {\n  padding-right: 10px;\n  list-style-type: none;\n}\n.crumb[data-v-5ccd4980]:not(:last-child):after {\n  content: var(--separator);\n  padding-left: 10px;\n}\n.link[data-v-5ccd4980] { text-decoration: none;\n}\n.-active[data-v-5ccd4980] { color: red\n}\n", map: {"version":3,"sources":["/Users/convenia/Desktop/convenia-spa/vue-coe-breadcrumb/src/components/CoeBreadcrumb.vue"],"names":[],"mappings":";AAgEA;CAAA;AAEA;EACA,cAAA;EACA,UAAA;EACA,WAAA;CACA;AAEA;EACA,oBAAA;EACA,sBAAA;CACA;AAEA;EACA,0BAAA;EACA,mBAAA;CACA;AAEA,yBAAA,sBAAA;CAAA;AAEA,4BAAA,UAAA;CAAA","file":"CoeBreadcrumb.vue","sourcesContent":["<template>\n  <div class=\"coe-breadcrumb\">\n    <slot name=\"crumbs\" :crumbs=\"$breadcrumb.crumbs\">\n      <ul class=\"breadcrumbs\">\n        <li v-for=\"(crumb, index) in $breadcrumb.crumbs\" :key=\"index\" :style=\"separator\" class=\"crumb\">\n          <component :is=\"getType(crumb)\" :class=\"getClasses(crumb)\" :to=\"redirect(crumb)\">\n            <slot name=\"crumbs\" :label=\"getLabel(crumb)\">{{ getLabel(crumb) }}</slot>\n          </component>\n        </li>\n      </ul>\n    </slot>\n  </div>\n</template>\n\n<script>\nexport default {\n  name: 'coe-breadcrumb',\n\n  watch: {\n    '$route': {\n      handler: 'syncRoute',\n      immediate: true\n    }\n  },\n\n  computed: {\n    separator () {\n      return { '--separator': `'${this.$breadcrumb.separator}'` }\n    }\n  },\n\n  methods: {\n    isActive (crumb) {\n      if (!crumb) return false\n\n      const currentName = this.$breadcrumb.crumbs.length && this.$breadcrumb.crumbs[this.$breadcrumb.crumbs.length - 1].name\n\n      return currentName === crumb.name\n    },\n\n    getType (crumb) {\n      return (this.isActive(crumb) && 'div') || 'router-link'\n    },\n\n    getClasses (crumb) {\n      return ['link', { '-active': this.isActive(crumb) }]\n    },\n\n    getLabel (crumb) {\n      return (crumb.label || crumb.name || 'Início')\n    },\n\n    redirect (crumb) {\n      return (!crumb.path && '/') || crumb\n    },\n\n    syncRoute ({ fullPath, name, matched, query, params }) {\n      this.$breadcrumb.syncRoute({ fullPath, name, matched, query, params })\n    }\n  }\n}\n</script>\n\n<style scoped>\n.coe-breadcrumb {}\n\n.breadcrumbs {\n  display: flex;\n  margin: 0;\n  padding: 0;\n}\n\n.crumb {\n  padding-right: 10px;\n  list-style-type: none;\n}\n\n.crumb:not(:last-child):after {\n  content: var(--separator);\n  padding-left: 10px;\n}\n\n.link { text-decoration: none; }\n\n.-active { color: red }\n</style>\n"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__ = "data-v-5ccd4980";
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* component normalizer */
  function __vue_normalize__(
    template, style, script$$1,
    scope, functional, moduleIdentifier,
    createInjector, createInjectorSSR
  ) {
    const component = (typeof script$$1 === 'function' ? script$$1.options : script$$1) || {};

    // For security concerns, we use only base name in production mode.
    component.__file = "/Users/convenia/Desktop/convenia-spa/vue-coe-breadcrumb/src/components/CoeBreadcrumb.vue";

    if (!component.render) {
      component.render = template.render;
      component.staticRenderFns = template.staticRenderFns;
      component._compiled = true;

      if (functional) component.functional = true;
    }

    component._scopeId = scope;

    {
      let hook;
      if (style) {
        hook = function(context) {
          style.call(this, createInjector(context));
        };
      }

      if (hook !== undefined) {
        if (component.functional) {
          // register for functional component in vue file
          const originalRender = component.render;
          component.render = function renderWithStyleInjection(h, context) {
            hook.call(context);
            return originalRender(h, context)
          };
        } else {
          // inject component registration as beforeCreate hook
          const existing = component.beforeCreate;
          component.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
      }
    }

    return component
  }
  /* style inject */
  function __vue_create_injector__() {
    const head = document.head || document.getElementsByTagName('head')[0];
    const styles = __vue_create_injector__.styles || (__vue_create_injector__.styles = {});
    const isOldIE =
      typeof navigator !== 'undefined' &&
      /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());

    return function addStyle(id, css) {
      if (document.querySelector('style[data-vue-ssr-id~="' + id + '"]')) return // SSR styles are present.

      const group = isOldIE ? css.media || 'default' : id;
      const style = styles[group] || (styles[group] = { ids: [], parts: [], element: undefined });

      if (!style.ids.includes(id)) {
        let code = css.source;
        let index = style.ids.length;

        style.ids.push(id);

        if (isOldIE) {
          style.element = style.element || document.querySelector('style[data-group=' + group + ']');
        }

        if (!style.element) {
          const el = style.element = document.createElement('style');
          el.type = 'text/css';

          if (css.media) el.setAttribute('media', css.media);
          if (isOldIE) {
            el.setAttribute('data-group', group);
            el.setAttribute('data-next-index', '0');
          }

          head.appendChild(el);
        }

        if (isOldIE) {
          index = parseInt(style.element.getAttribute('data-next-index'));
          style.element.setAttribute('data-next-index', index + 1);
        }

        if (style.element.styleSheet) {
          style.parts.push(code);
          style.element.styleSheet.cssText = style.parts
            .filter(Boolean)
            .join('\n');
        } else {
          const textNode = document.createTextNode(code);
          const nodes = style.element.childNodes;
          if (nodes[index]) style.element.removeChild(nodes[index]);
          if (nodes.length) style.element.insertBefore(textNode, nodes[index]);
          else style.element.appendChild(textNode);
        }
      }
    }
  }
  /* style inject SSR */
  

  
  var CoeBreadcrumb = __vue_normalize__(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    __vue_create_injector__,
    undefined
  )

export { index as VueCoeBreadcrumb, CoeBreadcrumb };
